==> v_chat_sdk-0.0.2.tar.gz: lib/src/utils/translator/ar_language.dart <==
import '../../../v_chat_sdk.dart';

class ArLanguage implements LookupString {
  @override
  String test() => "اختبار";

  @override
  String toDay() => "اليوم";

  @override
  String areYouSure()=>"هل انت متاكد";

  @override
  String cancel() =>"الغاء";

  @override
  String chatHasBeenClosed() =>"تم انهاء المحادثه";

  @override
  String chatHasBeenClosedByMe() =>"تم انهاء المحادثه من خلالي";

  @override
  String closeChat() =>"انهاء المحادثه";

  @override
  String connecting() =>"جاري الاتصال";

  @override
  String create() =>"انشاء";

  @override
  String enableNotification() =>"تفعيل التنبيهات";

  @override
  String failed() =>"فشل";

  @override
  String file() =>"ملف";

  @override
  String fileIsTooBig() =>"هذا الملف مساحته كبيره جدا";

  @override
  String friday() =>"الجمعه";

  @override
  String loadingPleaseWait() =>"برجاء الانتظار";

  @override
  String monday() =>"الاثنين";

  @override
  String muteNotification() =>"ايقاف التنبيهات";

  @override
  String notificationsHasBeenStoppedSuccessfully() =>"تم ايثاف التنبيهات بنجاح";

  @override
  String oK() =>"تم";

  @override
  String openChat() =>"افتح المحادثه";

  @override
  String photo() =>"صوره";

  @override
  String recording() =>"يقوم بتسجيل صوتي";

  @override
  String saturday()  =>"السبت";

  @override
  String sayHello()  =>"قل مرحبا";

  @override
  String showLess()  =>"اظهار اقل";

  @override
  String showMore()  =>"اظهر الكل";

  @override
  String success()  =>"نجحت";

  @override
  String sunday()  =>"الاحد";

  @override
  String thisOperationDoneSuccessfully()  =>"تمت العمليه بنجاح";

  @override
  String thisOperationFailed()  =>"فشلت العمليه";

  @override
  String thursday()  =>"الخميس";

  @override
  String tuesday()  =>"الثلاثاء";

  @override
  String typing()  =>"يكتب الان";

  @override
  String userHasBeenBlockedSuccessfully()  =>"تم انهاء المحادثه بنجاح";

  @override
  String video()  =>"فيديو";

  @override
  String wednesday()  =>"الاربعاء";

  @override
  String yesterday()  =>"الامس";

  @override
  String offline() => "غير متصل";

  @override
  String online() => "متصل";

  @override
  String yourMessage()=>"اكتب رساله";

}

==> v_chat_sdk-0.0.4.tar.gz: lib/src/utils/translator/ar_language.dart <==
import '../../../v_chat_sdk.dart';

class ArLanguage implements LookupString {
  @override
  String test() => "اختبار";

  @override
  String toDay() => "اليوم";

  @override
  String areYouSure()=>"هل انت متاكد";

  @override
  String cancel() =>"الغاء";

  @override
  String chatHasBeenClosed() =>"تم انهاء المحادثه";

  @override
  String chatHasBeenClosedByMe() =>"تم انهاء المحادثه من خلالي";

  @override
  String closeChat() =>"انهاء المحادثه";

  @override
  String connecting() =>"جاري الاتصال";

  @override
  String create() =>"انشاء";

  @override
  String enableNotification() =>"تفعيل التنبيهات";

  @override
  String failed() =>"فشل";

  @override
  String file() =>"ملف";

  @override
  String fileIsTooBig() =>"هذا الملف مساحته كبيره جدا";

  @override
  String friday() =>"الجمعه";

  @override
  String loadingPleaseWait() =>"برجاء الانتظار";

  @override
  String monday() =>"الاثنين";

  @override
  String muteNotification() =>"ايقاف التنبيهات";

  @override
  String notificationsHasBeenStoppedSuccessfully() =>"تم ايثاف التنبيهات بنجاح";

  @override
  String oK() =>"تم";

  @override
  String openChat() =>"افتح المحادثه";

  @override
  String photo() =>"صوره";

  @override
  String recording() =>"يقوم بتسجيل صوتي...";

  @override
  String saturday()  =>"السبت";

  @override
  String sayHello()  =>"قل مرحبا";

  @override
  String showLess()  =>"اظهار اقل";

  @override
  String showMore()  =>"اظهر الكل";

  @override
  String success()  =>"نجحت";

  @override
  String sunday()  =>"الاحد";

  @override
  String thisOperationDoneSuccessfully()  =>"تمت العمليه بنجاح";

  @override
  String thisOperationFailed()  =>"فشلت العمليه";

  @override
  String thursday()  =>"الخميس";

  @override
  String tuesday()  =>"الثلاثاء";

  @override
  String typing()  =>"يكتب الان ...";

  @override
  String userHasBeenBlockedSuccessfully()  =>"تم انهاء المحادثه بنجاح";

  @override
  String video()  =>"فيديو";

  @override
  String wednesday()  =>"الاربعاء";

  @override
  String yesterday()  =>"الامس";

  @override
  String offline() => "غير متصل";

  @override
  String online() => "متصل";

  @override
  String yourMessage()=>"اكتب رساله";

}
